@@ -24,6 +24,7 @@ class FieldKind(graphene.Enum):
     BOOLEAN = "boolean"
     INTEGER = "integer"
     DECIMAL = "decimal"
+    FLOAT = "float"
     DATE = "date"
     DATETIME = "datetime"
     TIME = "time"
@@ -114,7 +115,6 @@ def get_field_schema_int(field):
 
 
 @get_field_schema.register(models.DecimalField)
-@get_field_schema.register(models.FloatField)
 @get_field_schema.register(models.DurationField)
 def get_field_schema_decimal(field):
     return {
@@ -126,6 +126,13 @@ def get_field_schema_decimal(field):
     }
 
 
+@get_field_schema.register(models.FloatField)
+def get_field_schema_float(field):
+    return {
+        "kind": FieldKind.FLOAT,
+    }
+
+
 @get_field_schema.register(models.NullBooleanField)
 @get_field_schema.register(models.BooleanField)
 def get_field_schema_bool(field):
